@@ -1,5 +1,4 @@
 import threading
-import unittest
 
 import pytest
 from tornado import ioloop, web
@@ -16,24 +15,30 @@ from dummyserver.proxy import ProxyHandler
 
 
 def consume_socket(sock, chunks=65536):
-    while not sock.recv(chunks).endswith(b'\r\n\r\n'):
-        pass
+    consumed = bytearray()
+    while True:
+        b = sock.recv(chunks)
+        consumed += b
+        if b.endswith(b"\r\n\r\n"):
+            break
+    return consumed
 
 
-class SocketDummyServerTestCase(unittest.TestCase):
+class SocketDummyServerTestCase(object):
     """
     A simple socket-based server is created for this class that is good for
     exactly one request.
     """
-    scheme = 'http'
-    host = 'localhost'
+
+    scheme = "http"
+    host = "localhost"
 
     @classmethod
     def _start_server(cls, socket_handler):
         ready_event = threading.Event()
-        cls.server_thread = SocketServerThread(socket_handler=socket_handler,
-                                               ready_event=ready_event,
-                                               host=cls.host)
+        cls.server_thread = SocketServerThread(
+            socket_handler=socket_handler, ready_event=ready_event, host=cls.host
+        )
         cls.server_thread.start()
         ready_event.wait(5)
         if not ready_event.is_set():
@@ -62,40 +67,36 @@ class SocketDummyServerTestCase(unittest.TestCase):
     @classmethod
     def start_basic_handler(cls, **kw):
         return cls.start_response_handler(
-            b'HTTP/1.1 200 OK\r\n'
-            b'Content-Length: 0\r\n'
-            b'\r\n', **kw)
+            b"HTTP/1.1 200 OK\r\n" b"Content-Length: 0\r\n" b"\r\n", **kw
+        )
 
     @classmethod
-    def tearDownClass(cls):
-        if hasattr(cls, 'server_thread'):
+    def teardown_class(cls):
+        if hasattr(cls, "server_thread"):
             cls.server_thread.join(0.1)
 
     def assert_header_received(
-        self,
-        received_headers,
-        header_name,
-        expected_value=None
+        self, received_headers, header_name, expected_value=None
     ):
-        header_name = header_name.encode('ascii')
+        header_name = header_name.encode("ascii")
         if expected_value is not None:
-            expected_value = expected_value.encode('ascii')
+            expected_value = expected_value.encode("ascii")
         header_titles = []
         for header in received_headers:
-            key, value = header.split(b': ')
+            key, value = header.split(b": ")
             header_titles.append(key)
             if key == header_name and expected_value is not None:
-                self.assertEqual(value, expected_value)
-        self.assertIn(header_name, header_titles)
+                assert value == expected_value
+        assert header_name in header_titles
 
 
 class IPV4SocketDummyServerTestCase(SocketDummyServerTestCase):
     @classmethod
     def _start_server(cls, socket_handler):
         ready_event = threading.Event()
-        cls.server_thread = SocketServerThread(socket_handler=socket_handler,
-                                               ready_event=ready_event,
-                                               host=cls.host)
+        cls.server_thread = SocketServerThread(
+            socket_handler=socket_handler, ready_event=ready_event, host=cls.host
+        )
         cls.server_thread.USE_IPV6 = False
         cls.server_thread.start()
         ready_event.wait(5)
@@ -104,25 +105,27 @@ class IPV4SocketDummyServerTestCase(SocketDummyServerTestCase):
         cls.port = cls.server_thread.port
 
 
-class HTTPDummyServerTestCase(unittest.TestCase):
+class HTTPDummyServerTestCase(object):
     """ A simple HTTP server that runs when your test class runs
 
-    Have your unittest class inherit from this one, and then a simple server
+    Have your test class inherit from this one, and then a simple server
     will start when your tests run, and automatically shut down when they
     complete. For examples of what test requests you can send to the server,
     see the TestingApp in dummyserver/handlers.py.
     """
-    scheme = 'http'
-    host = 'localhost'
-    host_alt = '127.0.0.1'  # Some tests need two hosts
+
+    scheme = "http"
+    host = "localhost"
+    host_alt = "127.0.0.1"  # Some tests need two hosts
     certs = DEFAULT_CERTS
 
     @classmethod
     def _start_server(cls):
         cls.io_loop = ioloop.IOLoop.current()
         app = web.Application([(r".*", TestingApp)])
-        cls.server, cls.port = run_tornado_app(app, cls.io_loop, cls.certs,
-                                               cls.scheme, cls.host)
+        cls.server, cls.port = run_tornado_app(
+            app, cls.io_loop, cls.certs, cls.scheme, cls.host
+        )
         cls.server_thread = run_loop_in_thread(cls.io_loop)
 
     @classmethod
@@ -132,57 +135,60 @@ class HTTPDummyServerTestCase(unittest.TestCase):
         cls.server_thread.join()
 
     @classmethod
-    def setUpClass(cls):
+    def setup_class(cls):
         cls._start_server()
 
     @classmethod
-    def tearDownClass(cls):
+    def teardown_class(cls):
         cls._stop_server()
 
 
 class HTTPSDummyServerTestCase(HTTPDummyServerTestCase):
-    scheme = 'https'
-    host = 'localhost'
+    scheme = "https"
+    host = "localhost"
     certs = DEFAULT_CERTS
 
 
-@pytest.mark.skipif(not HAS_IPV6, reason='IPv6 not available')
+@pytest.mark.skipif(not HAS_IPV6, reason="IPv6 not available")
 class IPV6HTTPSDummyServerTestCase(HTTPSDummyServerTestCase):
-    host = '::1'
+    host = "::1"
 
 
-class HTTPDummyProxyTestCase(unittest.TestCase):
+class HTTPDummyProxyTestCase(object):
 
-    http_host = 'localhost'
-    http_host_alt = '127.0.0.1'
+    http_host = "localhost"
+    http_host_alt = "127.0.0.1"
 
-    https_host = 'localhost'
-    https_host_alt = '127.0.0.1'
+    https_host = "localhost"
+    https_host_alt = "127.0.0.1"
     https_certs = DEFAULT_CERTS
 
-    proxy_host = 'localhost'
-    proxy_host_alt = '127.0.0.1'
+    proxy_host = "localhost"
+    proxy_host_alt = "127.0.0.1"
 
     @classmethod
-    def setUpClass(cls):
+    def setup_class(cls):
         cls.io_loop = ioloop.IOLoop.current()
 
-        app = web.Application([(r'.*', TestingApp)])
+        app = web.Application([(r".*", TestingApp)])
         cls.http_server, cls.http_port = run_tornado_app(
-            app, cls.io_loop, None, 'http', cls.http_host)
+            app, cls.io_loop, None, "http", cls.http_host
+        )
 
-        app = web.Application([(r'.*', TestingApp)])
+        app = web.Application([(r".*", TestingApp)])
         cls.https_server, cls.https_port = run_tornado_app(
-            app, cls.io_loop, cls.https_certs, 'https', cls.http_host)
+            app, cls.io_loop, cls.https_certs, "https", cls.http_host
+        )
 
-        app = web.Application([(r'.*', ProxyHandler)])
+        app = web.Application([(r".*", ProxyHandler)])
         cls.proxy_server, cls.proxy_port = run_tornado_app(
-            app, cls.io_loop, None, 'http', cls.proxy_host)
+            app, cls.io_loop, None, "http", cls.proxy_host
+        )
 
         cls.server_thread = run_loop_in_thread(cls.io_loop)
 
     @classmethod
-    def tearDownClass(cls):
+    def teardown_class(cls):
         cls.io_loop.add_callback(cls.http_server.stop)
         cls.io_loop.add_callback(cls.https_server.stop)
         cls.io_loop.add_callback(cls.proxy_server.stop)
@@ -190,20 +196,20 @@ class HTTPDummyProxyTestCase(unittest.TestCase):
         cls.server_thread.join()
 
 
-@pytest.mark.skipif(not HAS_IPV6, reason='IPv6 not available')
+@pytest.mark.skipif(not HAS_IPV6, reason="IPv6 not available")
 class IPv6HTTPDummyServerTestCase(HTTPDummyServerTestCase):
-    host = '::1'
+    host = "::1"
 
 
-@pytest.mark.skipif(not HAS_IPV6, reason='IPv6 not available')
+@pytest.mark.skipif(not HAS_IPV6, reason="IPv6 not available")
 class IPv6HTTPDummyProxyTestCase(HTTPDummyProxyTestCase):
 
-    http_host = 'localhost'
-    http_host_alt = '127.0.0.1'
+    http_host = "localhost"
+    http_host_alt = "127.0.0.1"
 
-    https_host = 'localhost'
-    https_host_alt = '127.0.0.1'
+    https_host = "localhost"
+    https_host_alt = "127.0.0.1"
     https_certs = DEFAULT_CERTS
 
-    proxy_host = '::1'
-    proxy_host_alt = '127.0.0.1'
+    proxy_host = "::1"
+    proxy_host_alt = "127.0.0.1"
